vfbLib.typing.PSInfoDict
========================

.. currentmodule:: vfbLib.typing

.. autoclass:: PSInfoDict
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~PSInfoDict.__init__
      ~PSInfoDict.clear
      ~PSInfoDict.copy
      ~PSInfoDict.fromkeys
      ~PSInfoDict.get
      ~PSInfoDict.items
      ~PSInfoDict.keys
      ~PSInfoDict.pop
      ~PSInfoDict.popitem
      ~PSInfoDict.setdefault
      ~PSInfoDict.update
      ~PSInfoDict.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~PSInfoDict.font_matrix
      ~PSInfoDict.force_bold
      ~PSInfoDict.blue_values
      ~PSInfoDict.other_blues
      ~PSInfoDict.family_blues
      ~PSInfoDict.family_other_blues
      ~PSInfoDict.blue_scale
      ~PSInfoDict.blue_shift
      ~PSInfoDict.blue_fuzz
      ~PSInfoDict.std_hw
      ~PSInfoDict.std_vw
      ~PSInfoDict.stem_snap_h
      ~PSInfoDict.stem_snap_v
      ~PSInfoDict.bounding_box
      ~PSInfoDict.adv_width_min
      ~PSInfoDict.adv_width_max
      ~PSInfoDict.adv_width_avg
      ~PSInfoDict.ascender
      ~PSInfoDict.descender
      ~PSInfoDict.x_height
      ~PSInfoDict.cap_height
   
   